# Generated by Django 3.0.2 on 2020-02-03 19:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0007_auto_20200129_2215'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='_parsing_tags',
            field=models.CharField(choices=[('all_parse', 'All Tags'), ('relevant_parse', 'Relevant Tags (a, script, link, Form Tags, Meta Tags)'), ('form_parse', 'Form Tags (form, input, textarea, select, option)'), ('meta_parse', 'Meta Tags (meta, xmp)')], max_length=50),
        ),
    ]



# Generated by Django 3.0.2 on 2020-01-29 17:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0004_auto_20200129_1657'),
    ]

    operations = [
        migrations.AddField(
            model_name='webparsingjobmodel',
            name='cookies',
            field=models.TextField(null=True),
        ),
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='depth',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.0.2 on 2020-01-29 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0003_auto_20200129_1327'),
    ]

    operations = [
        migrations.AddField(
            model_name='webparsingjobmodel',
            name='json_file',
            field=models.CharField(default='---', max_length=250),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='webparsingjobmodel',
            name='url',
            field=models.CharField(default='---', max_length=512),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='parsing_tags',
            field=models.CharField(choices=[('all_parse', 'All Tags'), ('relevant_parse', 'Relevant Tags (a, script, link, Form Tags)'), ('form_parse', 'Form Tags (form, input, textarea, select, option)')], max_length=50),
        ),
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='parsing_type',
            field=models.CharField(choices=[('single_page', 'Single Page'), ('website_crawling', 'Website Crawling')], max_length=50),
        ),
    ]



# Generated by Django 3.0.2 on 2020-01-29 19:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0005_auto_20200129_1759'),
    ]

    operations = [
        migrations.RenameField(
            model_name='webparsingjobmodel',
            old_name='parsing_tags',
            new_name='_parsing_tags',
        ),
        migrations.RenameField(
            model_name='webparsingjobmodel',
            old_name='parsing_type',
            new_name='_parsing_type',
        ),
    ]



# Generated by Django 3.0.2 on 2020-01-29 13:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0002_webparsingjobmodel'),
    ]

    operations = [
        migrations.AddField(
            model_name='webparsingjobmodel',
            name='parsing_tags',
            field=models.CharField(choices=[('ALL_TAGS', 'All Tags'), ('RELEVANT_TAGS', 'Relevant Tags ()'), ('FORM_TAGS', 'Form Tags (form, input, textarea, select, option)')], default='ALL_TAGS', max_length=50),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='parsing_type',
            field=models.CharField(choices=[('SINGLE_PAGE', 'Single Page'), ('WEBSITE_CRAWLING', 'Website Crawling')], max_length=50),
        ),
    ]



#!/usr/bin/env python3

import os

from setuptools import setup


def find_packages(path, base="", exclude=()):
    """ Find all packages in path """
    packages = []
    for item in os.listdir(path):
        if item[0] == '.':
            continue
        if path in exclude:
            continue
        directory = os.path.join(path, item)
        if os.path.isdir(directory):
            if base:
                module_name = "%(base)s.%(item)s" % vars()
            else:
                module_name = item
            if module_name in exclude:
                continue
            packages.append(module_name)
            packages.extend(find_packages(directory, module_name, exclude))
    return packages


with open("./src/black_widow/README.md", "r") as fh:
    long_description = fh.read()


with open("./src/black_widow/requirements.txt", "r") as fh:
    install_requires = fh.readlines()


setup(
    name="black-widow",
    version='1.7.2',
    author="Fabrizio Fubelli",
    author_email="fabri.fubels@gmail.com",
    description="Offensive penetration testing tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://black-widow.eu",
    packages=find_packages(
        'src',
        exclude=(
            'black_widow.docker',
            'black_widow.docs',
            'black_widow.lessons',
            'black_widow.resources.logos',
            'black_widow.resources.social'
        )
    ),
    package_dir={
        '': 'src'
    },
    include_package_data=True,
    package_data={
        '': [
            '*.html',
            '*.css',
            '*.js',
            '*.eot', '*.svg', '*.ttf', '*.woff', '*.woff2',
            '*.png', '*.jpg', '*.ico',
            'LICENSE',
            'requirements.txt',
            'black-widow-ascii.txt'
            # 'web.wsgi'
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Natural Language :: English",
        "Topic :: Education :: Testing",
        'Topic :: Software Development :: Build Tools',
        "Topic :: System :: Clustering",
        "Topic :: System :: Monitoring",
        "Topic :: System :: Networking",
        "Topic :: System :: Hardware :: Symmetric Multi-processing",
        "Topic :: Utilities"
    ],
    entry_points={
        'console_scripts': [
            'black-widow = black_widow:main',
        ]
    },
    python_requires='>=3.6',
    keywords='black-widow penetration testing offensive cyber security pentest sniffing',
    project_urls={
        'Tracker': 'https://github.com/offensive-hub/black-widow/issues',
        'Source': 'https://github.com/offensive-hub/black-widow',
        'Documentation': 'https://docs.black-widow.io'
    },
    install_requires=install_requires
)
